##  Related Resources
Learn how to model SAP cloud solutions, S/4HANA, SAP Business Technology Platform (BTP), and SAP ERP 6.0 in the following pages:
  * [Modeling SAP Cloud Solutions](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions?locale=en-US&state=PRODUCTION&version=CLOUD "Understand the business and technical perspectives of modeling SAP Cloud Solutions and learn how to model them in SAP LeanIX.")
  * [Modeling S/4HANA](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana?locale=en-US&state=PRODUCTION&version=CLOUD "Understand the SAP S/4HANA application structure and the key difference between modeling the S/4HANA stack and the classic SAP ERP stack, and learn how to model S/4HANA in SAP LeanIX.")
  * [Modeling SAP BTP](https://help.sap.com/docs/leanix/ea/modeling-sap-btp?locale=en-US&state=PRODUCTION&version=CLOUD "Learn best practices for SAP BTP modeling, including guidelines for gaining insights and general approaches to structure your SAP BTP architecture.")
  * [Modeling SAP Interfaces and External Partners](https://help.sap.com/docs/leanix/ea/modeling-sap-interfaces-and-external-partners?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model SAP Interfaces and External Partners.")
  * [Modeling SAP ERP 6.0](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60?locale=en-US&state=PRODUCTION&version=CLOUD "Learn key approaches for modeling SAP ERP 6.0, including product versions, software components, technical components, and interfaces, as well as modeling system instances, such as local customizations.")


YesNo
Send
